pub enum MailboxRequest {
Put {
recipient: [u8; 32],
message: EncryptedMessage,
},
Fetch {
recipient: [u8; 32],
limit: usize,
},
Ack {
recipient: [u8; 32],
msg_ids: Vec<Uuid>,
},
}Expand description
Represents a request to a mailbox node.
Variants
Put
Request to put an encrypted message into the mailbox.
Fields

message: EncryptedMessageThe encrypted message to store.
Fetch
Request to fetch encrypted messages for a recipient.
Fields
Ack
Request to acknowledge and delete messages from the mailbox.